import typescriptEslint from "@typescript-eslint/eslint-plugin";
import globals from "globals";
import tsParser from "@typescript-eslint/parser";
import path from "node:path";
import { fileURLToPath } from "node:url";
import js from "@eslint/js";
import { FlatCompat } from "@eslint/eslintrc";

const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);
const compat = new FlatCompat({
    baseDirectory: __dirname,
    recommendedConfig: js.configs.recommended,
    allConfig: js.configs.all
});

export default [
    ...compat.extends("eslint:recommended", "plugin:@typescript-eslint/recommended", "prettier"),
    {
        plugins: {
            "@typescript-eslint": typescriptEslint,
        },

        languageOptions: {
            globals: {
                ...globals.node,
                ...globals.browser,
                ...globals.es2016,
            },

            parser: tsParser,
        },

        rules: {
            "@typescript-eslint/no-explicit-any": 0,
            "@typescript-eslint/ban-ts-comment": 0,
            "@typescript-eslint/no-non-null-assertion": 0,
            "no-async-promise-executor": 0,
            "@typescript-eslint/no-empty-interface": 0,
            "@typescript-eslint/no-unused-vars": 0,
            "@typescript-eslint/no-empty-object-type": 0,
            "@typescript-eslint/no-unsafe-declaration-merging": 0,
            "no-self-assign": 0,
            "@typescript-eslint/no-require-imports": 0,

            "no-constant-condition": ["error", {
                checkLoops: false,
            }],

            "prefer-const": ["error", {
                destructuring: "all",
                ignoreReadBeforeAssign: true,
            }],

            "@typescript-eslint/no-namespace": ["error", {
                allowDeclarations: true,
            }],
        },
    },
];
